@@ -7,8 +7,6 @@ from typing import Dict, Optional
 from fastapi import Request, Response
 from starlette import status
 
-from .request_enrichment import get_injected_body
-
 
 class LogContext:
     request_datetime: datetime
@@ -16,7 +14,6 @@ class LogContext:
     request_method: str
     request_headers: Dict[str, str]
     request_body: bytes
-    request_user_id: Optional[int]
 
     response_datetime: datetime
     response_status_code: int
@@ -61,18 +58,19 @@ class LogContext:
         log_context.request_headers = {}
         for k, v in request.headers.items():
             log_context.request_headers[k] = v
-        log_context.request_body = await get_injected_body(request)
+        log_context.request_body = await request.body()
         log_context.response_datetime = response_datetime
         log_context.elapsed_time = response_datetime - request_datetime
         if response is not None:
+            log_context.exception = None
             log_context.response_status_code = response.status_code
             log_context.response_body = await log_context.retrieve_response_body(response)
             log_context.response_headers = {}
             for k, v in response.headers.items():
                 log_context.response_headers[k] = v
         elif exception_traceback is not None:
-            log_context.response_status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
             log_context.exception = exception_traceback
+            log_context.response_status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
             log_context.response_body = None
             log_context.response_headers = None
         return log_context
